export type FunctionPropertyNames<T> = {
    [K in keyof T]: T[K] extends Function ? K : never;
}[keyof T];
export type FunctionProperties<T> = Pick<T, FunctionPropertyNames<T>>;
export type NonFunctionPropertyNames<T> = {
    [K in keyof T]: T[K] extends Function ? never : K;
}[keyof T];
export type NonFunctionProperties<T> = Pick<T, NonFunctionPropertyNames<T>>;
export type PartialNonFunctionProperties<T> = Partial<NonFunctionProperties<T>>;
/**
 * Array 의 filter 로 null/undefined 가 아닌 것을 걸러낼 때 사용한다.
 * ```ts
 * const array: (string | null)[] = ['test', null, 'sample', undefined]
 * const filtered: string[] = array.filter(notNull)
 * ```
 */
export declare function notNull<T>(value: T | null | undefined): value is T;
